{% extends 'base.html' %}


{% block class %}page page-{{ page.slug|to_css_class }}{% endblock %}


{% block title %}{{ page.title }} - {{ SITENAME }}{% endblock %}


{% block container %}
<div class="page-container">
    <div class="page-header">
        <h1>{{ page.title }}</h1>
    </div>
    <div class="page-content">
        {{ page.content }}
    </div>
</div>
{% endblock %}
